FlowChartConfig class abstract

Annotations
  • @JS.new()
  • @anonymous

Constructors

FlowChartConfig({bool htmlLabels, String curve})
factory

Properties

curve ↔ String
default: 'linear'
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
htmlLabels ↔ bool
htmlLabels - Flag for setting whether or not a html tag should be used for rendering labels on the edges default: true
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited